@@ -8,18 +8,18 @@
 
 #include "sddmsettings.h"
 #include "themesmodel.h"
-#include <KQuickAddons/ManagedConfigModule>
+#include <KQuickManagedConfigModule>
 class ThemeConfig;
 class AdvancedConfig;
 class SddmData;
 
-class SddmKcm : public KQuickAddons::ManagedConfigModule
+class SddmKcm : public KQuickManagedConfigModule
 {
     Q_OBJECT
     Q_PROPERTY(SddmSettings *sddmSettings READ sddmSettings CONSTANT)
     Q_PROPERTY(ThemesModel *themesModel READ themesModel CONSTANT)
 public:
-    explicit SddmKcm(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args);
+    explicit SddmKcm(QObject *parent, const KPluginMetaData &metaData);
     ~SddmKcm() override;
 
     Q_INVOKABLE static QString toLocalFile(const QUrl &url);
